==> rhymix-2.1.28.zip: rhymix/modules/board/lang/ko.php <==
<?php
$lang->board = '게시판';
$lang->except_notice = '공지사항 제외';
$lang->use_bottom_list = '하단목록 표시';
$lang->customize_bottom_list = '하단목록 설정';
$lang->use_anonymous = '익명 사용';
$lang->anonymous_except_admin = '관리자 익명 제외';
$lang->anonymous_name = '익명 닉네임';
$lang->cmd_manage_menu = '메뉴관리';
$lang->list_target_item = '대상 항목';
$lang->list_display_item = '표시 항목';
$lang->summary = '요약';
$lang->thumbnail = '섬네일';
$lang->last_post = '최종 글';
$lang->board_management = '게시판 관리';
$lang->search_result = '검색결과';
$lang->consultation = '상담 기능';
$lang->use_consultation = '상담 기능 사용';
$lang->secret = '비밀글 기능';
$lang->thisissecret = '비밀글입니다.';
$lang->admin_mail = '관리자 메일';
$lang->update_log = '게시글 수정 내역';
$lang->last_updater = '수정한 사람';
$lang->cmd_board_list = '게시판 목록';
$lang->cmd_module_config = '게시판 공통 설정';
$lang->cmd_board_info = '게시판 정보';
$lang->cmd_list_setting = '목록 설정';
$lang->cmd_list_items = '표시 항목 및 순서';
$lang->cmd_create_board = '게시판 등록';
$lang->cmd_manage_selected_board = '선택한 게시판 관리';
$lang->about_layout_setup = '블로그의 레이아웃 코드를 직접 수정할 수 있습니다. 위젯 코드를 원하는 곳에 삽입하시거나 관리하세요';
$lang->about_board_category = '분류를 만들 수 있습니다. 분류가 오동작을 할 경우 캐시파일 재생성을 수동으로 해주시면 해결이 될 수 있습니다.';
$lang->about_except_notice = '목록 상단에 늘 나타나는 공지사항을 일반 목록에 출력하지 않도록 합니다.<br />주의: 이용자와 게시물이 많은 게시판에서 이 옵션을 사용하면 DB 부하를 유발할 수 있습니다.';
$lang->about_use_bottom_list = '글읽기 화면 하단에도 목록을 표시합니다.';
$lang->about_customize_bottom_list = '게시물이 많은 경우 하단목록 계산에 많은 서버 자원이 소요됩니다.<br />불필요한 상황에서 하단목록을 계산하지 않도록 하면 DB 부하를 크게 줄일 수 있습니다.<br />검색 노출에는 영향을 주지 않습니다.';
$lang->about_use_anonymous_part1 = '글쓴이의 정보를 제거하고 익명으로 게시판을 사용하도록 합니다.';
$lang->about_use_anonymous_part2 = '스킨 설정에서 글쓴이 정보 등을 숨기도록 설정하면 더욱 유용합니다.<br>추가 설정에서 문서 히스토리가 켜져 있으면 문서 수정시 작성자가 표시될 수 있으니 주의하십시오.';
$lang->about_anonymous_except_admin = '관리권한이 있는 회원은 익명으로 표시되지 않도록 합니다.';
$lang->about_anonymous_name = '익명 기능을 사용할 때 표시할 익명 닉네임을 정할 수 있습니다.<br><b>$NUM</b>을 사용하면 회원마다 고유한 난수를 부여할 수 있습니다. (예: 익명_$NUM → 익명_12345678)<br><b>$DAILYNUM</b>을 사용하면 매일 난수가 변경되고, <b>$DOCNUM</b>을 사용하면 문서마다 변경됩니다.<br><b>$DOCDAILYNUM</b>을 사용하면 문서마다 각각, 그리고 매일 변경됩니다.<br>각 변수 뒤에 <strong>$DAILYNUM:5</strong>와 같이 1~8 숫자를 붙여 자릿수를 조정할 수 있습니다.<br><strong>NUM</strong> 대신 <strong>STR</strong>를 사용하면 일부 알파벳이 포함된 16진수를 사용합니다.';
$lang->about_board = '게시판을 생성하고 관리할 수 있습니다.';
$lang->about_consultation = '관리 권한이 없는 회원은 자신이 쓴 글만 보이도록 합니다.<br>상담 기능 사용시 비회원 글쓰기는 금지됩니다.';
$lang->about_secret = '게시판 및 댓글의 비밀글 기능을 사용할 수 있도록 합니다.';
$lang->about_admin_mail = '새 글이나 댓글이 등록되면 지정된 메일 주소로 알림을 받습니다. 여러 메일 주소를 지정하려면 쉼표(,)로 구분하세요.';
$lang->about_list_config = '게시판의 목록형식 사용시 원하는 항목들로 배치를 할 수 있습니다. 단 스킨에서 지원하지 않는 경우 불가능합니다. 대상항목/ 표시항목의 항목을 더블클릭하면 추가/ 제거가 됩니다.';
$lang->about_use_status = '글 작성 시 선택할 수 있는 상태를 지정해주세요.';
$lang->about_protect_comment = '댓글의 댓글이 있을경우 해당댓글을 삭제 및 수정을 할 수 없도록 합니다.';
$lang->about_update_log = '게시글을 수정할 경우 수정한 내역을 저장하도록 합니다.';
$lang->skip_bottom_list_for_olddoc = '오래된 게시물 열람시 하단 목록을 정확하게 계산하지 않음';
$lang->skip_bottom_list_for_robot = '로봇 방문시 하단 목록을 정확하게 계산하지 않음';
$lang->msg_not_enough_point = '포인트가 부족합니다';
$lang->write_comment = '댓글 쓰기';
$lang->msg_not_allow_comment = '해당 글의 댓글 쓰기가 잠겨있습니다.';
$lang->no_board_instance = '생성된 게시판이 없습니다.';
$lang->choose_board_instance = '관리할 게시판을 선택해 주세요.';
$lang->comment_status = '댓글 허용 여부';
$lang->category_settings = '분류 설정';
$lang->hide_category = '분류 숨기기';
$lang->about_hide_category = '분류 사용을 임시로 중단합니다. 사용하던 분류는 삭제되지 않습니다.<br>아래의 &quot;미분류 허용&quot;을 선택하지 않으면 글을 쓰지 못하게 될 수 있습니다.';
$lang->allow_no_category = '미분류 허용';
$lang->about_allow_no_category = '분류를 선택하지 않고 글을 쓸 수 있도록 합니다.<br>체크하지 않아도 관리자는 항상 분류 없이 글을 쓸 수 있습니다.';
$lang->protect_content = '글 보호 기능';
$lang->protect_comment = '댓글 보호 기능';
$lang->protect_admin_content = '최고관리자 보호 기능';
$lang->protect_regdate = '기간 제한 기능';
$lang->filter_specialchars = '유니코드 특수문자 오남용 금지';
$lang->document_length_limit = '문서 길이 제한';
$lang->comment_length_limit = '댓글 길이 제한';
$lang->inline_data_url_limit = 'Data URL 제한';
$lang->about_document_length_limit = '지나치게 용량이 큰 글을 작성하지 못하도록 합니다. 지저분한 태그가 많이 붙은 글을 붙여넣으면 제한을 초과할 수도 있습니다.<br>관리자에게는 적용되지 않습니다.';
$lang->about_comment_length_limit = '지나치게 용량이 큰 댓글을 작성하지 못하도록 합니다.<br>관리자에게는 적용되지 않습니다.';
$lang->about_inline_data_url_limit = 'data: URL을 사용하여 첨부 제한을 우회하거나 처리 장애를 일으키는 내용을 제한합니다.<br>이 설정은 관리자에게도 적용됩니다.';
$lang->update_order_on_comment = '댓글 작성시 글 수정 시각 갱신';
$lang->about_update_order_on_comment = '댓글이 작성되면 해당 글의 수정 시각을 갱신합니다. 포럼형 게시판, 최근 댓글 표시 기능 등에 필요합니다.';
$lang->about_filter_specialchars = '가독성에 악영향을 주는 과도한 유니코드 악센트 기호의 조합, RLO 문자 등의 사용을 금지합니다.';
$lang->about_protect_regdate = '글이나 댓글을 작성한 후 일정 기간이 지나면 수정 또는 삭제할 수 없도록 합니다. (단위 : day)';
$lang->about_protect_content = '댓글이 달린 글은 수정 또는 삭제할 수 없도록 합니다.';
$lang->about_protect_admin_content = '최고관리자가 작성한 글이나 댓글은 게시판 관리 권한이 있는 회원이라도 수정 또는 삭제할 수 없도록 합니다.';
$lang->msg_protect_delete_content = '댓글이 달린 글은 삭제할 수 없습니다.';
$lang->msg_protect_update_content = '댓글이 달린 글은 수정할 수 없습니다.';
$lang->msg_admin_document_no_modify = '최고관리자의 게시물을 수정할 권한이 없습니다.';
$lang->msg_admin_comment_no_modify = '최고관리자의 댓글을 수정할 권한이 없습니다.';
$lang->msg_board_delete_protect_comment = '대댓글이 달린 댓글은 삭제할 수 없습니다.';
$lang->msg_board_update_protect_comment = '대댓글이 달린 댓글은 수정할 수 없습니다.';
$lang->msg_protect_regdate_document = '%d일 이상 지난 글은 수정 또는 삭제할 수 없습니다.';
$lang->msg_protect_regdate_comment = '%d일 이상 지난 댓글은 수정 또는 삭제할 수 없습니다.';
$lang->msg_dont_have_update_log = '업데이트 로그가 기록되어 있지 않은 게시글입니다.';
$lang->msg_content_too_long = '내용이 너무 깁니다.';
$lang->msg_data_url_restricted = 'Data URL 분량이 너무 많아서 작성이 제한되었습니다.';
$lang->original_letter = '원본글';
$lang->msg_warning_update_log = '<span class="x_label x_label-important">주의!</span> 사용시 DB 용량이 많이 늘어날 수 있습니다.';
$lang->reason_update = '수정한 이유';
$lang->msg_no_update_id = '업데이트 고유 번호는 필수입니다.';
$lang->msg_no_update_log = '업데이트 로그가 존재하지 않습니다.';
$lang->cmd_modify_by_update_log = '이 로그로 게시물을 수정하기';
$lang->msg_admin_update_log = '관리자가 수정한 적이 있는 게시물입니다. 관리자에게 문의하세요.';
$lang->msg_update_log_revert = '정말로 이 버전으로 되돌리시겠습니까?';
$lang->write_admin = '관리자작성';
$lang->revert_reason_update = '이 버전으로 되돌림';
$lang->document_force_to_move = '삭제시 휴지통 사용';
$lang->about_document_force_to_move = '게시물 삭제시 완전히 지우지 않고 휴지통으로 옮깁니다.';
$lang->comment_delete_message = '댓글 자리 남김';
$lang->about_comment_delete_message = '댓글 삭제시 완전히 지우지 않고 "삭제된 댓글"이라는 메시지를 남깁니다.';
$lang->cmd_only_p_comment = '대댓글이 있는 경우에만 남김';
$lang->cmd_all_comment_message = '모든 댓글에 남김';
$lang->cmd_do_not_message = '남기지 않음';
$lang->delete_placeholder = '완전 삭제';
$lang->msg_document_notify_mail = '[%s] 새로운 게시글이 등록되었습니다 : %s';
$lang->cmd_document_vote_user = '이 글의 추천인 목록';
$lang->cmd_comment_vote_user = '이 댓글의 추천인 목록';
$lang->msg_not_target = '문서 또는 댓글의 추천인목록만 조회가능합니다.';
$lang->cmd_board_combined_board = '통합 게시판';
$lang->about_board_combined_board = '다른 게시판의 글을 모아서 볼 수 있습니다. 여러 게시판을 선택하려면 Ctrl 키를 누르고 클릭하세요.<br /><span style="color:red">주의: 현재 게시판의 권한 설정이 모든 글에 적용됩니다.</span>';
$lang->cmd_board_include_modules = '포함할 게시판 선택';
$lang->cmd_board_include_modules_none = '(포함하지 않음)';
$lang->cmd_board_include_days = '포함할 기간';
$lang->about_board_include_days = '최근 글만 모으도록 설정할 수 있습니다. 0을 입력하면 위에서 선택한 게시판의 모든 글을 모아서 보여 줍니다.<br />1일 미만의 기간은 소수로 표현할 수 있습니다. 예: 0.25일 = 6시간';
$lang->cmd_board_include_notice = '공지글 포함';

==> rhymix-2.1.30.zip: rhymix/modules/board/lang/ko.php <==
<?php
$lang->board = '게시판';
$lang->board_special_features = '특이사항';
$lang->except_notice = '공지사항 제외';
$lang->use_bottom_list = '하단목록 표시';
$lang->customize_bottom_list = '하단목록 설정';
$lang->use_anonymous = '익명 사용';
$lang->anonymous_except_admin = '관리자 익명 제외';
$lang->anonymous_name = '익명 닉네임';
$lang->cmd_manage_menu = '메뉴관리';
$lang->list_target_item = '대상 항목';
$lang->list_display_item = '표시 항목';
$lang->summary = '요약';
$lang->thumbnail = '섬네일';
$lang->last_post = '최종 글';
$lang->board_management = '게시판 관리';
$lang->search_result = '검색결과';
$lang->consultation = '상담 기능';
$lang->use_consultation = '상담 기능 사용';
$lang->secret = '비밀글 기능';
$lang->thisissecret = '비밀글입니다.';
$lang->admin_mail = '관리자 메일';
$lang->update_log = '게시글 수정 내역';
$lang->last_updater = '수정한 사람';
$lang->cmd_board_list = '게시판 목록';
$lang->cmd_module_config = '게시판 공통 설정';
$lang->cmd_board_info = '게시판 정보';
$lang->cmd_list_setting = '목록 설정';
$lang->cmd_list_items = '표시 항목 및 순서';
$lang->cmd_create_board = '게시판 등록';
$lang->cmd_manage_selected_board = '선택한 게시판 관리';
$lang->about_layout_setup = '블로그의 레이아웃 코드를 직접 수정할 수 있습니다. 위젯 코드를 원하는 곳에 삽입하시거나 관리하세요';
$lang->about_board_category = '분류를 만들 수 있습니다. 분류가 오동작을 할 경우 캐시파일 재생성을 수동으로 해주시면 해결이 될 수 있습니다.';
$lang->about_except_notice = '목록 상단에 늘 나타나는 공지사항을 일반 목록에 출력하지 않도록 합니다.<br />주의: 이용자와 게시물이 많은 게시판에서 이 옵션을 사용하면 DB 부하를 유발할 수 있습니다.';
$lang->about_use_bottom_list = '글읽기 화면 하단에도 목록을 표시합니다.';
$lang->about_customize_bottom_list = '게시물이 많은 경우 하단목록 계산에 많은 서버 자원이 소요됩니다.<br />불필요한 상황에서 하단목록을 계산하지 않도록 하면 DB 부하를 크게 줄일 수 있습니다.<br />검색 노출에는 영향을 주지 않습니다.';
$lang->about_use_anonymous_part1 = '글쓴이의 정보를 제거하고 익명으로 게시판을 사용하도록 합니다.';
$lang->about_use_anonymous_part2 = '스킨 설정에서 글쓴이 정보 등을 숨기도록 설정하면 더욱 유용합니다.<br>추가 설정에서 문서 히스토리가 켜져 있으면 문서 수정시 작성자가 표시될 수 있으니 주의하십시오.';
$lang->about_anonymous_except_admin = '관리권한이 있는 회원은 익명으로 표시되지 않도록 합니다.';
$lang->about_anonymous_name = '익명 기능을 사용할 때 표시할 익명 닉네임을 정할 수 있습니다.<br><b>$NUM</b>을 사용하면 회원마다 고유한 난수를 부여할 수 있습니다. (예: 익명_$NUM → 익명_12345678)<br><b>$DAILYNUM</b>을 사용하면 매일 난수가 변경되고, <b>$DOCNUM</b>을 사용하면 문서마다 변경됩니다.<br><b>$DOCDAILYNUM</b>을 사용하면 문서마다 각각, 그리고 매일 변경됩니다.<br>각 변수 뒤에 <strong>$DAILYNUM:5</strong>와 같이 1~8 숫자를 붙여 자릿수를 조정할 수 있습니다.<br><strong>NUM</strong> 대신 <strong>STR</strong>를 사용하면 일부 알파벳이 포함된 16진수를 사용합니다.';
$lang->about_board = '게시판을 생성하고 관리할 수 있습니다.';
$lang->about_consultation = '관리 권한이 없는 회원은 자신이 쓴 글만 보이도록 합니다.<br>상담 기능 사용시 비회원 글쓰기는 금지됩니다.';
$lang->about_secret = '게시판 및 댓글의 비밀글 기능을 사용할 수 있도록 합니다.';
$lang->about_admin_mail = '새 글이나 댓글이 등록되면 지정된 메일 주소로 알림을 받습니다. 여러 메일 주소를 지정하려면 쉼표(,)로 구분하세요.';
$lang->about_list_config = '게시판의 목록형식 사용시 원하는 항목들로 배치를 할 수 있습니다. 단 스킨에서 지원하지 않는 경우 불가능합니다. 대상항목/ 표시항목의 항목을 더블클릭하면 추가/ 제거가 됩니다.';
$lang->about_use_status = '글 작성 시 선택할 수 있는 상태를 지정해주세요.';
$lang->about_update_log = '게시글을 수정할 경우 수정한 내역을 저장하도록 합니다.';
$lang->skip_bottom_list_for_olddoc = '오래된 게시물 열람시 하단 목록을 정확하게 계산하지 않음';
$lang->skip_bottom_list_for_robot = '로봇 방문시 하단 목록을 정확하게 계산하지 않음';
$lang->msg_not_enough_point = '포인트가 부족합니다';
$lang->write_comment = '댓글 쓰기';
$lang->msg_not_allow_comment = '해당 글의 댓글 쓰기가 잠겨있습니다.';
$lang->no_board_instance = '생성된 게시판이 없습니다.';
$lang->choose_board_instance = '관리할 게시판을 선택해 주세요.';
$lang->comment_status = '댓글 허용 여부';
$lang->category_settings = '분류 설정';
$lang->hide_category = '분류 숨기기';
$lang->about_hide_category = '분류 사용을 임시로 중단합니다. 사용하던 분류는 삭제되지 않습니다.<br>아래의 &quot;미분류 허용&quot;을 선택하지 않으면 글을 쓰지 못하게 될 수 있습니다.';
$lang->allow_no_category = '미분류 허용';
$lang->about_allow_no_category = '분류를 선택하지 않고 글을 쓸 수 있도록 합니다.<br>체크하지 않아도 관리자는 항상 분류 없이 글을 쓸 수 있습니다.';
$lang->protect_content = '글 보호 기능';
$lang->protect_comment = '댓글 보호 기능';
$lang->protect_admin_content = '최고관리자 보호 기능';
$lang->protect_regdate = '기간 제한 기능';
$lang->filter_specialchars = '유니코드 특수문자 오남용 금지';
$lang->document_length_limit = '문서 길이 제한';
$lang->comment_length_limit = '댓글 길이 제한';
$lang->inline_data_url_limit = 'Data URL 제한';
$lang->about_document_length_limit = '지나치게 용량이 큰 글을 작성하지 못하도록 합니다. 지저분한 태그가 많이 붙은 글을 붙여넣으면 제한을 초과할 수도 있습니다.<br>관리자에게는 적용되지 않습니다.';
$lang->about_comment_length_limit = '지나치게 용량이 큰 댓글을 작성하지 못하도록 합니다.<br>관리자에게는 적용되지 않습니다.';
$lang->about_inline_data_url_limit = 'data: URL을 사용하여 첨부 제한을 우회하거나 처리 장애를 일으키는 내용을 제한합니다.<br>이 설정은 관리자에게도 적용됩니다.';
$lang->update_order_on_comment = '댓글 작성시 글 수정 시각 갱신';
$lang->about_update_order_on_comment = '댓글이 작성되면 해당 글의 수정 시각을 갱신합니다. 포럼형 게시판, 최근 댓글 표시 기능 등에 필요합니다.';
$lang->about_filter_specialchars = '가독성에 악영향을 주는 과도한 유니코드 악센트 기호의 조합, RLO 문자 등의 사용을 금지합니다.';
$lang->about_protect_content_update = '댓글이 %d개 이상 달린 글은 수정할 수 없도록 합니다.';
$lang->about_protect_content_delete = '댓글이 %d개 이상 달린 글은 삭제할 수 없도록 합니다.';
$lang->about_protect_comment_update = '대댓글이 %d개 이상 달린 댓글은 수정할 수 없도록 합니다.';
$lang->about_protect_comment_delete = '대댓글이 %d개 이상 달린 댓글은 삭제할 수 없도록 합니다.';
$lang->about_protect_document_regdate = '작성 후 %d일 이상 지난 글은 수정 또는 삭제할 수 없도록 합니다.';
$lang->about_protect_comment_regdate = '작성 후 %d일 이상 지난 댓글은 수정 또는 삭제할 수 없도록 합니다.';
$lang->about_protect_admin_content = '최고관리자가 작성한 글이나 댓글은 게시판 관리 권한이 있는 회원이라도 수정 또는 삭제할 수 없도록 합니다.';
$lang->msg_protect_update_content = '댓글이 %d개 이상 달린 글은 수정할 수 없습니다.';
$lang->msg_protect_delete_content = '댓글이 %d개 이상 달린 글은 삭제할 수 없습니다.';
$lang->msg_board_update_protect_comment = '대댓글이 %d개 이상 달린 댓글은 수정할 수 없습니다.';
$lang->msg_board_delete_protect_comment = '대댓글이 %d개 이상 달린 댓글은 삭제할 수 없습니다.';
$lang->msg_admin_document_no_modify = '최고관리자의 게시물을 수정할 권한이 없습니다.';
$lang->msg_admin_comment_no_modify = '최고관리자의 댓글을 수정할 권한이 없습니다.';
$lang->msg_protect_regdate_document = '%d일 이상 지난 글은 수정 또는 삭제할 수 없습니다.';
$lang->msg_protect_regdate_comment = '%d일 이상 지난 댓글은 수정 또는 삭제할 수 없습니다.';
$lang->msg_dont_have_update_log = '업데이트 로그가 기록되어 있지 않은 게시글입니다.';
$lang->msg_content_too_long = '내용이 너무 깁니다.';
$lang->msg_data_url_restricted = 'Data URL 분량이 너무 많아서 작성이 제한되었습니다.';
$lang->original_letter = '원본글';
$lang->msg_warning_update_log = '<span class="x_label x_label-important">주의!</span> 사용시 DB 용량이 많이 늘어날 수 있습니다.';
$lang->reason_update = '수정한 이유';
$lang->msg_no_update_id = '업데이트 고유 번호는 필수입니다.';
$lang->msg_no_update_log = '업데이트 로그가 존재하지 않습니다.';
$lang->cmd_modify_by_update_log = '이 로그로 게시물을 수정하기';
$lang->msg_admin_update_log = '관리자가 수정한 적이 있는 게시물입니다. 관리자에게 문의하세요.';
$lang->msg_update_log_revert = '정말로 이 버전으로 되돌리시겠습니까?';
$lang->write_admin = '관리자작성';
$lang->revert_reason_update = '이 버전으로 되돌림';
$lang->document_force_to_move = '삭제시 휴지통 사용';
$lang->about_document_force_to_move = '게시물 삭제시 완전히 지우지 않고 휴지통으로 옮깁니다.';
$lang->comment_delete_message = '댓글 자리 남김';
$lang->about_comment_delete_message = '댓글 삭제시 완전히 지우지 않고 "삭제된 댓글"이라는 메시지를 남깁니다.';
$lang->cmd_only_p_comment = '대댓글이 있는 경우에만 남김';
$lang->cmd_all_comment_message = '모든 댓글에 남김';
$lang->cmd_do_not_message = '남기지 않음';
$lang->delete_placeholder = '완전 삭제';
$lang->msg_document_notify_mail = '[%s] 새로운 게시글이 등록되었습니다 : %s';
$lang->cmd_document_vote_user = '이 글의 추천인 목록';
$lang->cmd_comment_vote_user = '이 댓글의 추천인 목록';
$lang->msg_not_target = '문서 또는 댓글의 추천인목록만 조회가능합니다.';
$lang->cmd_board_combined_board = '통합 게시판';
$lang->about_board_combined_board = '다른 게시판의 글을 모아서 볼 수 있습니다. 여러 게시판을 선택하려면 Ctrl 키를 누르고 클릭하세요.<br /><span style="color:red">주의: 현재 게시판의 권한 설정이 모든 글에 적용됩니다.</span>';
$lang->cmd_board_include_modules = '포함할 게시판 선택';
$lang->cmd_board_include_modules_none = '(포함하지 않음)';
$lang->cmd_board_include_days = '포함할 기간';
$lang->about_board_include_days = '최근 글만 모으도록 설정할 수 있습니다. 0을 입력하면 위에서 선택한 게시판의 모든 글을 모아서 보여 줍니다.<br />1일 미만의 기간은 소수로 표현할 수 있습니다. 예: 0.25일 = 6시간';
$lang->cmd_board_include_notice = '공지글 포함';
